package data.missions.cocktailparty;

import com.fs.starfarer.api.campaign.CargoAPI.CrewXPLevel;
import com.fs.starfarer.api.fleet.FleetGoal;
import com.fs.starfarer.api.fleet.FleetMemberAPI;
import com.fs.starfarer.api.fleet.FleetMemberType;
import com.fs.starfarer.api.mission.FleetSide;
import com.fs.starfarer.api.mission.MissionDefinitionAPI;
import com.fs.starfarer.api.mission.MissionDefinitionPlugin;

public class MissionDefinition implements MissionDefinitionPlugin {

	public void defineMission(MissionDefinitionAPI api) {

		// Set up the fleets
		api.initFleet(FleetSide.PLAYER, "CDS", FleetGoal.ATTACK, false, 5);
		api.initFleet(FleetSide.ENEMY, "TTS", FleetGoal.ATTACK, true, 5);

		// Set a blurb for each fleet
		api.setFleetTagline(FleetSide.PLAYER, "Citadel Convoy Defense");
		api.setFleetTagline(FleetSide.ENEMY, "Tri-Tachyon containment task force");
		
		// These show up as items in the bulleted list under 
		// "Tactical Objectives" on the mission detail screen
		api.addBriefingItem("The CDS Allen Wrench must survive");

		
		// Set up the player's fleet
		api.addToFleet(FleetSide.PLAYER, "Fox_MDestroyer_breaker", FleetMemberType.SHIP, "CDS Allen Wrench", true, CrewXPLevel.ELITE);
		api.addToFleet(FleetSide.PLAYER, "Fox_LDestroyer_breaker", FleetMemberType.SHIP, false, CrewXPLevel.VETERAN).getCaptain().setPersonality("suicidal");
		
		api.addToFleet(FleetSide.PLAYER, "atlas_Standard", FleetMemberType.SHIP, false, CrewXPLevel.GREEN).getCaptain().setPersonality("cowardly");
		api.addToFleet(FleetSide.PLAYER, "atlas_Standard", FleetMemberType.SHIP, false, CrewXPLevel.GREEN).getCaptain().setPersonality("cowardly");
		api.addToFleet(FleetSide.PLAYER, "Fox_Carrier_standard", FleetMemberType.SHIP, false, CrewXPLevel.GREEN).getCaptain().setPersonality("cowardly");
		api.addToFleet(FleetSide.PLAYER, "Fox_Corvette_standard", FleetMemberType.SHIP, false, CrewXPLevel.GREEN).getCaptain().setPersonality("cowardly");
		api.addToFleet(FleetSide.PLAYER, "Fox_Corvette_standard", FleetMemberType.SHIP, false, CrewXPLevel.GREEN).getCaptain().setPersonality("cowardly");
		api.addToFleet(FleetSide.PLAYER, "Fox_Frigate_standard", FleetMemberType.SHIP, false).getCaptain().setPersonality("cautious");
		api.addToFleet(FleetSide.PLAYER, "Fox_Frigate_standard", FleetMemberType.SHIP, false).getCaptain().setPersonality("cautious");
		
		api.addToFleet(FleetSide.PLAYER, "fox_arrowhead_wing", FleetMemberType.FIGHTER_WING, false);
		api.addToFleet(FleetSide.PLAYER, "fox_arrowhead_wing", FleetMemberType.FIGHTER_WING, false);		
		api.addToFleet(FleetSide.PLAYER, "fox_heak_wing", FleetMemberType.FIGHTER_WING, false);
		api.addToFleet(FleetSide.PLAYER, "fox_heak_wing", FleetMemberType.FIGHTER_WING, false);	
		api.addToFleet(FleetSide.PLAYER, "fox_mako_wing", FleetMemberType.FIGHTER_WING, false);
		// Mark player flagship as essential
		api.defeatOnShipLoss("CDS Allen Wrench");
		
		// Set up the enemy fleet
		api.addToFleet(FleetSide.ENEMY, "apogee_Balanced", FleetMemberType.SHIP, "TTS Ephemeral", false);
		api.addToFleet(FleetSide.ENEMY, "medusa_Attack", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "medusa_Attack", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "shade_Assault", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "wolf_CS", FleetMemberType.SHIP, false);
		//api.addToFleet(FleetSide.ENEMY, "wolf_CS", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "tempest_Attack", FleetMemberType.SHIP, false);
		//api.addToFleet(FleetSide.ENEMY, "tempest_Attack", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "omen_PD", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.ENEMY, "omen_PD", FleetMemberType.SHIP, false);
		
		api.addToFleet(FleetSide.ENEMY, "wasp_wing", FleetMemberType.FIGHTER_WING, false);
		api.addToFleet(FleetSide.ENEMY, "xyphos_wing", FleetMemberType.FIGHTER_WING, false);
		api.addToFleet(FleetSide.ENEMY, "xyphos_wing", FleetMemberType.FIGHTER_WING, false);
		api.addToFleet(FleetSide.ENEMY, "longbow_wing", FleetMemberType.FIGHTER_WING, false);
		api.addToFleet(FleetSide.ENEMY, "dagger_wing", FleetMemberType.FIGHTER_WING, false);

		
		
		// Set up the map.
		float width = 5000f;
		float height = 10000f;
		api.initMap((float)-width/2f, (float)width/2f, (float)-height/2f, (float)height/2f);
		
		float minX = -width/2;
		float minY = -height/2;
		
		for (int i = 0; i < 15; i++) {
			float x = (float) Math.random() * width - width/2;
			float y = (float) Math.random() * height - height/2;
			float radius = 100f + (float) Math.random() * 900f; 
			api.addNebula(x, y, radius);
		}
		
		api.addNebula(minX + width * 0.8f, minY + height * 0.4f, 2000);
		api.addNebula(minX + width * 0.8f, minY + height * 0.5f, 2000);
		api.addNebula(minX + width * 0.8f, minY + height * 0.6f, 2000);
		
		api.addObjective(minX + width * 0.8f, minY + height * 0.4f, "nav_buoy");
		api.addObjective(minX + width * 0.8f, minY + height * 0.6f, "nav_buoy");
		api.addObjective(minX + width * 0.3f, minY + height * 0.3f, "comm_relay");
		api.addObjective(minX + width * 0.3f, minY + height * 0.7f, "comm_relay");
		api.addObjective(minX + width * 0.5f, minY + height * 0.5f, "sensor_array");
		api.addObjective(minX + width * 0.2f, minY + height * 0.5f, "sensor_array");
		
		// Add an asteroid field going diagonally across the
		// battlefield, 2000 pixels wide, with a maximum of 
		// 100 asteroids in it.
		// 20-70 is the range of asteroid speeds.
		api.addAsteroidField(minX + width * 0.3f, minY, 90, 3000f,
								20f, 70f, 50);
		
		// Add some planets.  These are defined in data/config/planets.json.
		api.addPlanet(minX + width * 0.2f + 600, minY + height * 0.5f, 350f, "ice_giant", 200f);
		api.addPlanet(minX + width * 0.75f + 600, minY + height * 0.3f, 200f, "cryovolcanic", 100f);
	}

}






